summaryrefslogtreecommitdiff
path: root/Master/tlpkg/bin
diff options
context:
space:
mode:
authorNorbert Preining <preining@logic.at>2007-06-18 14:23:18 +0000
committerNorbert Preining <preining@logic.at>2007-06-18 14:23:18 +0000
commitdfd6e494fcfcfe684312b959c68d589b06d33594 (patch)
tree9d14cbe7b574ddcb88afbc910ab89a4af4c7f7cf /Master/tlpkg/bin
parent7fb60a74aab3febff8b73f2c8485f038d6a5e8cf (diff)
it is tlpsrc not tlsrc, tlpobj not tlp, tlpdb not tldb...
git-svn-id: svn://tug.org/texlive/trunk@4469 c570f23f-e606-0410-a88d-b1316a301751
Diffstat (limited to 'Master/tlpkg/bin')
-rwxr-xr-xMaster/tlpkg/bin/tlpobj2tlpdb.pl22
-rwxr-xr-xMaster/tlpkg/bin/tlpsrc2tlpdb.pl12
-rwxr-xr-xMaster/tlpkg/bin/tlpsrc2tlpobj.pl22
-rwxr-xr-xMaster/tlpkg/bin/update-tlpdb6
4 files changed, 31 insertions, 31 deletions
diff --git a/Master/tlpkg/bin/tlpsrc2tlpobj.pl b/Master/tlpkg/bin/tlpsrc2tlpobj.pl
index 58f7dff61d7..6b3a57282cb 100755
--- a/Master/tlpkg/bin/tlpsrc2tlpobj.pl
+++ b/Master/tlpkg/bin/tlpsrc2tlpobj.pl
@@ -1,6 +1,6 @@
#!/usr/bin/env perl
#
-# tlsrc2tlp.pl
+# tlpsrc2tlpobj.pl
# convert a set of tlsrc files (given as arguments) into tlp
# Copyright 2007 Norbert Preining
#
@@ -11,14 +11,14 @@
BEGIN {
$^W = 1;
($mydir = $0) =~ s,/[^/]*$,,;
- unshift (@INC, $mydir);
+ unshift (@INC, "$mydir/..");
}
use strict;
-use TLSRC;
-use TLP;
-use TLTREE;
+use TeXLive::TLPSRC;
+use TeXLive::TLPOBJ;
+use TeXLive::TLTREE;
use Getopt::Long;
use Pod::Usage;
use File::Path;
@@ -47,11 +47,11 @@ if (! -d "$opt_outputdir") {
mkpath("$opt_outputdir") or die "Cannot mkdir $opt_outputdir!";
}
-my $tltree = TLTREE->new( 'svnroot' => "$opt_master" );
+my $tltree = TeXLive::TLTREE->new( 'svnroot' => "$opt_master" );
$tltree->init_from_svn;
foreach my $f (@ARGV) {
- my $tlsrc = new TLSRC;
+ my $tlsrc = new TeXLive::TLPSRC;
$tlsrc->from_file($f);
my $tlp = $tlsrc->make_tlp($tltree);
my $name = $tlp->name;
@@ -65,11 +65,11 @@ __END__
=head1 NAME
-tlsrc2tlp - Converting tlsrc files into tlp files
+tlpsrc2tlpobj - Converting tlpsrc files into tlpobj files
=head1 SYNOPSIS
-tlsrc2tlp [options] [tlsrcfiles ...]
+tlpsrc2tlpobj [options] [tlpsrcfiles ...]
Options:
-help brief help message
@@ -107,8 +107,8 @@ Give debug messages from the TeX Live modules
=head1 DESCRIPTION
-B<tlsrc2tlp> converts TeX Live Source (tlsrc) files into TeX Live Package
-files (tlp).
+B<tlpsrc2tlpobj> converts TeX Live Package Source files (tlpsrc) into
+TeX Live Package Object files (tlpobj).
=cut
diff --git a/Master/tlpkg/bin/update-tlpdb b/Master/tlpkg/bin/update-tlpdb
index 13bf29021a2..90a1b0a1bef 100755
--- a/Master/tlpkg/bin/update-tlpdb
+++ b/Master/tlpkg/bin/update-tlpdb
@@ -2,7 +2,7 @@
# Norbert Preining
# these scripts are in Master/tlpkg/bin
cd $(dirname $0)/../..
-perl tlpkg/bin/tlsrc2tldb.pl tlpkg/tlsrc/*.tlsrc > texlive.tldb.new
-mv texlive.tldb texlive.tldb.saved
-mv texlive.tldb.new texlive.tldb
+perl tlpkg/bin/tlpsrc2tlpdb.pl tlpkg/tlpsrc/*.tlpsrc > texlive.tlpdb.new
+mv texlive.tlpdb texlive.tlpdb.saved
+mv texlive.tlpdb.new texlive.tlpdb
diff --git a/Master/tlpkg/bin/tlpobj2tlpdb.pl b/Master/tlpkg/bin/tlpobj2tlpdb.pl
index c7ce7a97bc2..ec9081982a8 100755
--- a/Master/tlpkg/bin/tlpobj2tlpdb.pl
+++ b/Master/tlpkg/bin/tlpobj2tlpdb.pl
@@ -1,7 +1,7 @@
#!/usr/bin/env perl
#
# tlp2tldb.pl
# convert a set of tlp files (given as arguments) into a tldb
# Copyright 2007 Norbert Preining
#
# This file is licensed under the GNU General Public Licence version 2
@@ -11,13 +11,13 @@
BEGIN {
$^W = 1;
($mydir = $0) =~ s,/[^/]*$,,;
- unshift (@INC, $mydir);
+ unshift (@INC, "$mydir/..");
}
use strict;
-use TLP;
-use TLDB;
+use TeXLive::TLPOBJ;
+use TeXLive::TLPDB;
use Getopt::Long;
use Pod::Usage;
use File::Path;
@@ -31,9 +31,9 @@ GetOptions("debug!", 'help|?' => \$help, man => \$man) or pod2usage(2);
pod2usage(1) if $help;
pod2usage(-exitstatus => 0, -verbose => 2) if $man;
-my $tldb = TLDB->new;
+my $tldb = TeXLive::TLPDB->new;
foreach my $f (@ARGV) {
- my $tlp = new TLP;
+ my $tlp = new TeXLive::TLPOBJ;
$tlp->from_file($f);
$tldb->add_tlp($tlp);
}
@@ -44,11 +44,11 @@ __END__
=head1 NAME
-tlp2tldb - Converting tlp files into a tldb file
+tlpobj2tlpdb - Converting tlp files into a tldb file
=head1 SYNOPSIS
-tlp2tldb [options] [tlsrcfiles ...]
+tlpobj2tlpdb [options] [tlpobj-files ...]
Options:
-help brief help message
@@ -76,8 +76,8 @@ Give debug messages from the TeX Live modules
=head1 DESCRIPTION
-B<tlp2tldb> converts TeX Live Package (tlp) files into TeX Live Database
-(tldb).
+B<tlpobj2tlpdb> converts TeX Live Object Package files (tlpobj) files
+into TeX Live Package Database (tlpdb).
=cut
@@ -1,7 +1,7 @@
#!/usr/bin/env perl
#
-# tlp2tldb.pl
-# convert a set of tlp files (given as arguments) into a tldb
+# tlpobj2tlpdb.pl
+# convert a set of tlpobj files (given as arguments) into a tlpdb
# Copyright 2007 Norbert Preining
#
diff --git a/Master/tlpkg/bin/tlpsrc2tlpdb.pl b/Master/tlpkg/bin/tlpsrc2tlpdb.pl
index 8eadecb1828..2ef2443cb70 100755
--- a/Master/tlpkg/bin/tlpsrc2tlpdb.pl
+++ b/Master/tlpkg/bin/tlpsrc2tlpdb.pl
@@ -1,6 +1,6 @@
#!/usr/bin/env perl
# tlsrc2tldb.pl
# convert a set of tlsrc files (given as arguments) into tldb
#
# Copyright 2007 Norbert Preining
# This file is licensed under the GNU General Public Licence version 2
@@ -58,11 +58,11 @@ __END__
=head1 NAME
-tlsrc2tldb - Converting tlsrc files into tldb file
+tlpsrc2tlpdb - Converting tlpsrc files into tlpdb file
=head1 SYNOPSIS
-tlsrc2tldb [options] [tlsrcfiles ...]
+tlpsrc2tlpdb [options] [tlsrcfiles ...]
Options:
-help brief help message
@@ -95,8 +95,8 @@ Give debug messages from the TeX Live modules
=head1 DESCRIPTION
-B<tlsrc2tldb> converts TeX Live Source (tlsrc) files into TeX Live Database
-(tldb).
+B<tlpsrc2tlpdb> converts TeX Live Source Package files (tlpsrc) files into a
+TeX Live Package Database (tlpdb).
=head1 AUTHORS AND COPYRIGHT
@@ -1,6 +1,6 @@
#!/usr/bin/env perl
-# tlsrc2tldb.pl
-# convert a set of tlsrc files (given as arguments) into tldb
+# tlpsrc2tlpdb.pl
+# convert a set of tlpsrc files (given as arguments) into tlpdb
#
# Copyright 2007 Norbert Preining